Module blaxel.core.client.models.workspace_runtime
==================================================

Classes
-------

`WorkspaceRuntime(generation: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>)`
:   Workspace runtime
    
    Attributes:
        generation (Union[Unset, str]): Workspace generation
    
    Method generated by attrs for class WorkspaceRuntime.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `generation: blaxel.core.client.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :